// JavaScript Document

//	===============================
//	  No 047 ： a_2_P156_001.js
//	  p.156　指数関数とそのグラフ
//	===============================

//	+------+
//	| 変数 |
//	+------+

// キャンバス、ステージ
var cc;
var cs;

// キャンバスの幅、高さ
var bW;
var bH;
var cW;
var cH;

// 中心位置
var centerX;
var centerY;

// Ｘ軸、Ｙ軸
var axisX;
var axisY;

// Ｘ軸、Ｙ軸、原点テキスト
var tx;
var ty;
var t0;

// 軸線
var base;

// 方眼
var grid;

// 刻み幅
var stepSize;

// １目盛りのピクセル数
var span;

// １周期のピクセル
var baseCycle;

// グラフ共通の右下の歯車ボタンで使用する設定データ
var configArray;

// 軌跡を制御する場合
var recCont;
var recData;

// アニメーション制御用スライダー
var slider;
var animeFlag;

// ドラッグ関連
var prevX;
var prevY;
var dFlag;

// 既定値関連
var defMin;
var defMax;
var defNum;

// 図形用
var shp;						// 線、破線、円など
var SHAPE_LINE_1	=	0;		// 線１
var SHAPE_LINE_2	=	1;		// 線２
var SHAPE_DLINE_1	=	2;		// 破線１
var SHAPE_DOT_1		=	3;		// 座標点１
var SHAPE_DOT_2		=	4;		// 座標点２
var SHAPE_DOT_3		=	5;		// 座標点３
var SHAPE_MAX		=	6;		// 図形の数
var nameTbl = [ "line1", "line2", "dotLine1", "Dot1", "Dot2", "Dot3"];

// キャンバスに表示するテキスト
var txt;
var TEXT_F1_1		=	0;		// 式用
var TEXT_F1_2		=	1;		// 式用
var TEXT_DOT1_X		=	2;		// 座標点１X
var TEXT_DOT1_Y		=	3;		// 座標点１Y
var TEXT_DOT2_X		=	4;		// 座標点２X
var TEXT_DOT2_Y		=	5;		// 座標点２Y
var TEXT_DOT3_X		=	6;		// 座標点３X
var TEXT_DOT3_Y		=	7;		// 座標点３Y
var TEXT_MAX		=	8;		// テキストの数

// コンテナに入れるテキスト
var conText;
var cnt;
var CONT_F2_1		=	0;		// 式用
var CONT_F2_2		=	1;		// 式用
var CONT_F2_3		=	2;		// 式用
var CONT_F2_4		=	3;		// 式用
var CONT_F2_5		=	4;		// 式用
var CONT_MAX		=	5;		// テキストの数

// 値保存用
var aNum;
var t1x;
var t1y;
var t2x;
var t2y;


//	+----------------+
//	| ロード時の処理 |
//	+----------------+
function loadContentHandler()
{
	try
	{
		// ----------
		// 初期値設定
		// ----------
		
		// １周期のピクセル
		baseCycle = 300;
		
		// 軸の1目盛当たりのピクセル数
		span = 60;
		
		// 刻み幅
		stepSize = 0.1;
		
		// キャンバスサイズ設定
		bW = pageWidth-52;
		bH = pageHeight;
		cW = bW * 3;
		cH = bH * 3;
		document.getElementById("graphBlock").style.width = bW + "px";
		document.getElementById("graphBlock").style.height = bH + "px";
		document.getElementById("graphCanvas").style.left = (-bW + 120) + "px";
		document.getElementById("graphCanvas").style.top = (-bH + 90) + "px";
		document.getElementById("graphCanvas").width = cW;
		document.getElementById("graphCanvas").height = cH;
		document.getElementById("graphCanvas").style.position = "absolute";
		
		// 中心位置
		centerX = cW/2;
		centerY = cH/2;
		
		// 値の上限、下限、既定値
		defMin = 0;
		defMax = 5;
		defNum = 2;
		
		// ドラッグ関連
		dFlag = true;
		animeFlag = false;
		
		// 状態の記録エリア
		recData = [];
		
		// 変数初期化
		aNum = 2;
		
		// ------------
		// 画面関連設定
		// ------------
		
		// アニメーションスライダを吹き出しで使用する場合
		var animStep = Math.round((defMax-defMin) / 7 * 100) / 100;
		slider = new AnimeBalloon( defMin, defMax, defNum, 250, 40, false, animStep, changeAnimeGraph, captureData, resetCapture );
		
		// ステージの作成
		cc = document.getElementById("graphCanvas");
		cs = new createjs.Stage(cc);
		createjs.Touch.enable(cs);
		
		// 背景の作成
		var bg = new createjs.Shape();
		bg.graphics.beginFill("#FFF");
		bg.graphics.drawRect(0, 0, cW, cH);
		bg.graphics.endFill();
		cs.addChild(bg);
		
		// 方眼の作成
		grid = new createjs.Shape();
		cs.addChild(grid);
		
		// 軸と矢印の作成
		base = new createjs.Shape();
		cs.addChild(base);
		axisX = new createjs.Shape();
		cs.addChild(axisX);
		axisY = new createjs.Shape();
		cs.addChild(axisY);
		
		// Ｘ軸、Ｙ軸、原点のテキスト作成
		tx = new createjs.Text("x", "italic 20px Times New Roman", "#000000");
		cs.addChild(tx);
		ty = new createjs.Text("y", "italic 20px Times New Roman", "#000000");
		cs.addChild(ty);
		t0 = new createjs.Text("O", "20px Times New Roman", "#000000");
		cs.addChild(t0);
		
		// キャンパスに表示する図形
		shp = [];
		for ( var i=0; i<SHAPE_MAX; i++ )	{
			shp[i] = new createjs.Shape();
			shp[i].name = nameTbl[i];
			cs.addChild(shp[i]);
		}
		
		// キャンバスに表示するテキスト
		txt = [];
		for ( var i=0; i<TEXT_MAX; i++ )	{
			switch( i )
			{
				case TEXT_F1_1:
					txt[i] = new createjs.Text("", "18px Times New Roman", "#000000");
					break;
				case TEXT_F1_2:
					txt[i] = new createjs.Text("x", "12px Times New Roman", "#000000");
					break;
				case TEXT_DOT1_X:
				case TEXT_DOT1_Y:
				case TEXT_DOT2_X:
				case TEXT_DOT2_Y:
				case TEXT_DOT3_X:
				case TEXT_DOT3_Y:
					txt[i] = new createjs.Text("", "18px Times New Roman", "#000000");
					break;
				default:
					txt[i] = new createjs.Text("", "18px Times New Roman", "#000000");
					break;
			}
			cs.addChild(txt[i]);
		}
		
		// 分数表示用のコンテナ作成
		conText = new createjs.Container();
		cs.addChild(conText);
		cnt = [];
		cnt[CONT_F2_1] = new createjs.Text("x", "12px Times New Roman", "#000000");
		cnt[CONT_F2_2] = new createjs.Text("y=(    )", "18px Times New Roman", "#000000");
		cnt[CONT_F2_3] = new createjs.Text("1", "12px Times New Roman", "#000000");
		cnt[CONT_F2_4] = new createjs.Text("ー", "12px Times New Roman", "#000000");
		cnt[CONT_F2_5] = new createjs.Text("", "12px Times New Roman", "#000000");
		for ( var i=0; i<CONT_MAX; i++ )	{	conText.addChild(cnt[i]);	}
		
		// 状態記録のコンテナ作成
		recCont = new createjs.Container();
		cs.addChild(recCont);
		
		$(".lineText").focus(function(){$(this).blur();});
		
		$(".configText").css("display", "inline-block");
		$(".configText").css("width", "40px");
		
		// 入力欄の設定
		document.getElementById("xNum").style.textAlign = "center";
		document.getElementById("xNum").style.width = "30px";
		document.getElementById("xNum").style.display = "inline-block";
		
		// 設定吹き出し
		configArray = [];
		configArray[0] = [-30, 360, -10, 10];
		configArray[1] = [null, null];
		configArray[2] = [null, null];
		setGraphConfig();
		
		// チェックボックス
		document.getElementById("check0").checked = true;
		document.getElementById("check1").checked = true;
		document.getElementById("check2").checked = true;
		document.getElementById("check3").checked = false;
		document.getElementById("check4").checked = false;
		
		//-------------
		// リスナー定義
		//-------------
		// リセット
		document.getElementById('resetBtn').addEventListener('click', resetHandler);
		// 刻み幅
		document.getElementById("stepText").addEventListener("click", openMenuBalloonHandler);
		// チェックボックス
		document.getElementById("check0").addEventListener("change", changeCheckHandler);
		document.getElementById("check1").addEventListener("change", changeCheckHandler);
		document.getElementById("check2").addEventListener("change", changeCheckHandler);
		document.getElementById("check3").addEventListener("change", changeCheckHandler);
		document.getElementById("check4").addEventListener("change", changeCheckHandler);
		// 線のドラッグ
//		shp[SHAPE_LINE_K].addEventListener("mousedown", lineDragStart);
		// ドットのドラッグ
//		shp[SHAPE_DOT_A].addEventListener("mousedown", dotDragStart);
		// キャンバスのドラッグ
		cs.addEventListener("mousedown", canvasDragStart);
		// オプションボタン（数式の設定画面）
		document.getElementById("optionBtn0").addEventListener('click', openOptionHandler);
		document.getElementById("optionClose0").addEventListener('click', closeOptionHandler);
		// 数式の設定
		document.getElementById("upBtn0_0").addEventListener("click", changeFormulaHandler);
		document.getElementById("downBtn0_0").addEventListener("click", changeFormulaHandler);
		// 値の設定
		document.getElementById("upBtn0").addEventListener("click", changeDataHandler);
		document.getElementById("downBtn0").addEventListener("click", changeDataHandler);
		
		//-------------
		// 画面初期表示
		//-------------
		
		// 使用しないバルーン・非表示
		document.getElementById("selectBalloon_menu").style.display = "none";			// 刻み幅
		document.getElementById("selectBalloon_config").style.display = "none";			// 設定画面
		//document.getElementById("animeBalloon").style.display = "none";					// アニメ
		
		// スライダー設定
		document.getElementById("loopBtn").src = "./img/loopIcon.png";
		document.getElementById('speedConfig').src = "./img/s1.png";
		slider.min = defMin;
		slider.max = defMax;
		slider.prev = defNum;
		slider.loopFlag = false;
		slider.loopMode = 0;
		slider.span = stepSize;
		slider.speedIndex = 2;
		slider.changeSliderLine();
		slider.changeSliderPoint();
		slider.changeSliderControl();
		
		document.getElementById("xNum").innerHTML = slider.prev;
		
		// 刻み幅
//		document.getElementById("stepText").innerHTML = stepSize;
		
		// 軸表示
		drawBaseLine();
		changeAxisPositionHandler();
		
		// 計算処理
		calcData();
		
		// 式の表示
		drawFormula();
		
		// 図形の表示
		drawShape();
		
		// テキストの表示
		drawText();
		
		// オプションメニュー画面
		setModal('optionBlock');
		setModal('spanChange');
		setMenuMode(0, 320);
		
		// ステージ更新
		slider.ss.update();
		cs.update();
		
		// バージョンチェック
		checkVersionHandler("1.0.0");
	}
	catch(e)
	{
		alert("loadContentHandler:" + e.toString());
	}
}

//	+------------------------------------+
//	| 以下は必要なので削除してはいけない |
//	+------------------------------------+

//	+--------------------------+
//	| アニメ制御画面のオープン |
//	+--------------------------+
function setAnimeBalloonPosition()
{
	document.getElementById("animeTriangle").style = "position:relative;left:108px";
}

//	+----------------+
//	| アニメーション |
//	+----------------+
function changeAnimeGraph()
{
	document.getElementById('xNum').innerHTML = Math.round( slider.prev * 100 ) / 100;
	calcData();
	drawFormula();
	drawShape();
	drawText();
	slider.ss.update();
	cs.update();
}

//	+--------------+
//	|  |
//	+--------------+
function changeFormulaPositionHandler(num)
{
	return;
}
//	+--------------+
//	|  |
//	+--------------+
function captureData()
{
	try
	{
		var xNum = document.getElementById("xNum").innerHTML;
		createcaptureData(xNum);
		cs.update();
	}
	catch(e)
	{
		alert("captureData:" + e.toString());
	}
}

//	+--------------+
//	|  |
//	+--------------+
function createcaptureData(n)
{
	try
	{
		if( document.getElementById("check2").checked )
		{
			var s = new createjs.Shape();
			s.name = "s" + recData.length;
			cs.addChild(s);
			
			s.x = n;
			s.y = Math.pow(aNum, n);
			s.alpha = 0.25;
			
			drawDot(s, s.x, s.y, "blue", s.alpha);
			
			recCont.addChild(s);
		}
		if( document.getElementById("check3").checked )
		{
			var s = new createjs.Shape();
			s.name = "s" + recData.length;
			cs.addChild(s);
			
			s.x = n;
			s.y = Math.pow(1 / aNum, n);
			s.alpha = 0.25;
			drawDot(s, s.x, s.y, "blue", s.alpha);
			recCont.addChild(s);
		}
		if( document.getElementById("check4").checked )
		{
			var s = new createjs.Shape();
			s.name = "s" + recData.length;
			cs.addChild(s);
			
			s.x = -n;
			s.y = Math.pow(1 / aNum, -n);
			s.alpha = 0.25;
			drawDot(s, s.x, s.y, "blue", s.alpha);
			recCont.addChild(s);
		}
		recData.push(n);
		cs.update();
	}
	catch(e)
	{
		alert("createcaptureData:" + e.toString());
	}
		
}

//	+--------------+
//	|  |
//	+--------------+
function resetCapture()
{
	try
	{
		var leng = recData.length;
		//オブジェクトを削除
		recCont.removeAllChildren();
		//データの削除
		recData = [];
		cs.update();
	}
	catch(e)
	{
		alert("resetCapture:" + e.toString());
	}
}
//	+----------------------------------------+
//	| ここまでは必要なので削除してはいけない |
//	+----------------------------------------+

//	+--------------------+
//	| ベースラインの描画 |
//	+--------------------+
function drawBaseLine()
{
	try
	{
		// 軸と矢印の描画
		base.graphics.setStrokeStyle(1);
		base.graphics.beginStroke("#000000");
		// Ｘ軸
		base.graphics.moveTo(0, cH/2);
		base.graphics.lineTo(cW, cH/2);
		// Ｙ軸
		base.graphics.moveTo(cW/2, 0);
		base.graphics.lineTo(cW/2, cH);
		// Ｘ軸の矢印
		axisX.graphics.beginFill("#000000");
		axisX.graphics.moveTo(-20, 0);
		axisX.graphics.lineTo(-20, -4);
		axisX.graphics.lineTo(-2, 0);
		axisX.graphics.lineTo(-20, 4);
		axisX.graphics.lineTo(-20, 0);
		axisX.graphics.endFill();
		// Ｙ軸の矢印
		axisY.graphics.beginFill("#000000");
		axisY.graphics.moveTo(0, 20);
		axisY.graphics.lineTo(-4, 20);
		axisY.graphics.lineTo(0, 2);
		axisY.graphics.lineTo(4, 20);
		axisY.graphics.lineTo(0, 20);
		axisY.graphics.endFill();
		axisY.graphics.endStroke();
		// Ｘ軸、Ｙ軸の位置
		var numX = document.getElementById("graphCanvas").style.left;
		var numY = document.getElementById("graphCanvas").style.top;
		numX = -numX.substring(0, numX.length-2);
		numY = -numY.substring(0, numY.length-2);
		axisX.x = numX + bW;
		axisX.y = centerY;
		axisY.x = centerX;
		axisY.y = numY;
		// Ｘ軸、Ｙ軸、原点のテキスト
		tx.x = numX + bW -tx.getBounds().width-5;
		tx.y = cH/2+5;
		ty.x = cW/2+10;
		ty.y = numY + 2;
		t0.x = cW/2+5;
		t0.y = cH/2+5;
	}
	catch(e)
	{
		alert("drawBase:"+e.toString());
	}
}

//	+----------+
//	| 軸の表示 |
//	+----------+
function changeAxisPositionHandler()
{
	try
	{
		var numX = document.getElementById("graphCanvas").style.left;
		var numY = document.getElementById("graphCanvas").style.top;
		
		numX = -numX.substring(0, numX.length-2)/cScale;
		numY = -numY.substring(0, numY.length-2)/cScale;
		
		axisX.x = numX + bW/cScale;
		axisY.y = numY;
		
		base.graphics.clear();
		
		base.graphics.setStrokeStyle(1);
		base.graphics.beginStroke("#000000");
		
		//x軸
		base.graphics.moveTo(0, cH/2);
		base.graphics.lineTo(axisX.x-2, cH/2);
		//y軸
		base.graphics.moveTo(cW/2, axisY.y+2);
		base.graphics.lineTo(cW/2, cH);
		
		//軸のテキスト
		tx.x = axisX.x -tx.getBounds().width-5;
		ty.y = axisY.y + 2;
	}
	catch(e)
	{
		alert("changeAxisPositionHandler:" + e.toString());
	}
}

//	+----------+
//	| 計算処理 |
//	+----------+
function calcData()
{
	try
	{
		t1x = 2;
		t1y = Math.min(Math.pow( aNum, t1x ), 8.0);
		t2x = -2;
		t2y = Math.min(1 / Math.pow( aNum, t2x ), 8.0);
	}
	catch(e)
	{
		alert("calcData:" + e.toString());
	}
}

//	+------------+
//	| 図形の表示 |
//	+------------+
function drawShape()
{
	try
	{
		for ( var i=0; i<SHAPE_MAX; i++ )		{	shp[i].graphics.clear();	}
		
		if ( document.getElementById('check0').checked )
		{
			shp[SHAPE_LINE_1].graphics.setStrokeStyle(1);
			shp[SHAPE_LINE_1].graphics.beginStroke( "#000000" );
			var x = -10;
			var y = Math.pow(aNum,x);
			shp[SHAPE_LINE_1].graphics.moveTo( centerX + x * span, centerY - y * span );
			for ( var x=-10; x<11; x+=0.25 )
			{
				y = Math.pow(aNum,x);
				shp[SHAPE_LINE_1].graphics.lineTo( centerX + x * span, centerY - y * span );
			}
			shp[SHAPE_LINE_1].graphics.endStroke();
		}
		
		if ( document.getElementById('check1').checked )
		{
			shp[SHAPE_LINE_2].graphics.setStrokeStyle(1);
			shp[SHAPE_LINE_2].graphics.beginStroke( "#000000" );
			var x = -10;
			var y = 1 / Math.pow(aNum, x);
			shp[SHAPE_LINE_2].graphics.moveTo( centerX + x * span, centerY - y * span );
			for ( var x=-10; x<11; x+=0.25 )
			{
				y = 1 / Math.pow(aNum, x);
				shp[SHAPE_LINE_2].graphics.lineTo( centerX + x * span, centerY - y * span );
			}
			shp[SHAPE_LINE_2].graphics.endStroke();
		}
		
		var xNum = document.getElementById("xNum").innerHTML;
		if( document.getElementById("check2").checked )
		{
			var y = Math.pow(aNum, xNum);
			drawDot(shp[SHAPE_DOT_1], xNum, y, "blue", 0.5);
			drawDotLine(shp[SHAPE_DLINE_1], xNum, y, "black", 1.0);
		}
		
		if( document.getElementById("check3").checked )
		{
			var y = Math.pow(1 / aNum, xNum);
			drawDot(shp[SHAPE_DOT_2], xNum, y, "blue", 0.5);
			drawDotLine(shp[SHAPE_DLINE_1], xNum, y, "black", 1.0);
		}
		if( document.getElementById("check4").checked )
		{
			var y = Math.pow(1 / aNum, -xNum);
			drawDot(shp[SHAPE_DOT_3], -xNum, y, "blue", 0.5);
			drawDotLine(shp[SHAPE_DLINE_1], -xNum, y, "black", 1.0);
		}
	}
	catch(e)
	{
		alert("drawShape:" + e.toString());
	}
}

//	+----------------+
//	| テキストの表示 |
//	+----------------+
function drawText()
{
	try
	{
		for ( var i=0; i<TEXT_MAX; i++ )	{	txt[i].visible = false;	}
		conText.visible = false;
		
		
		if ( document.getElementById('check0').checked )
		{
			var x = 0;
			txt[TEXT_F1_1].text = "y=" + aNum;
			txt[TEXT_F1_1].x = centerX + t1x * span + 10;
			txt[TEXT_F1_1].y = centerY - t1y * span - 24;
			if ( ( ( aNum * 10 ) % 10 ) != 0 )		{	x = 14;	}
			txt[TEXT_F1_2].x = centerX + t1x * span + 38 + x;
			txt[TEXT_F1_2].y = centerY - t1y * span - 28;
			txt[TEXT_F1_1].visible = true;
			txt[TEXT_F1_2].visible = true;
		}
		
		if ( document.getElementById('check1').checked )
		{
			drawCont(aNum);
		}
		
		if( document.getElementById("check2").checked )
		{
			var xNum = document.getElementById("xNum").innerHTML;
			txt[TEXT_DOT1_X].text = xNum;
			txt[TEXT_DOT1_Y].text = Math.round( Math.pow(aNum, xNum) * 100) / 100;
			txt[TEXT_DOT1_X].visible = true;
			txt[TEXT_DOT1_Y].visible = true;
			drawPosText2(txt[TEXT_DOT1_X], txt[TEXT_DOT1_Y]);
		}
		
		if( document.getElementById("check3").checked )
		{
			var xNum = document.getElementById("xNum").innerHTML;
			txt[TEXT_DOT2_X].text = xNum;
			txt[TEXT_DOT2_Y].text = Math.round( Math.pow(1 / aNum, xNum) * 100) / 100;
			txt[TEXT_DOT2_X].visible = true;
			txt[TEXT_DOT2_Y].visible = true;
			drawPosText2(txt[TEXT_DOT2_X], txt[TEXT_DOT2_Y]);
		}
		
		if( document.getElementById("check4").checked )
		{
			var xNum = document.getElementById("xNum").innerHTML;
			txt[TEXT_DOT3_X].text = -xNum;
			txt[TEXT_DOT3_Y].text = Math.round( Math.pow(1 / aNum, -xNum) * 100) / 100;
			txt[TEXT_DOT3_X].visible = true;
			txt[TEXT_DOT3_Y].visible = true;
			drawPosText2(txt[TEXT_DOT3_X], txt[TEXT_DOT3_Y]);
		}
	}
	catch(e)
	{
		alert("drawText:" + e.toString());
	}
}

//	+--------------------+
//	| 分数テキストの表示 |
//	+--------------------+
function drawCont(a,x,y)
{
	try
	{
		cnt[CONT_F2_1].x = 49;
		cnt[CONT_F2_1].y = 0;
		cnt[CONT_F2_2].x = 0;
		cnt[CONT_F2_2].y = 6;
		cnt[CONT_F2_3].x = 32;
		cnt[CONT_F2_3].y = 2;
		cnt[CONT_F2_4].x = 28;
		cnt[CONT_F2_4].y = 10;
		cnt[CONT_F2_5].text = a;
		if ( ( ( a * 10 ) % 10 ) == 0 )		{	cnt[CONT_F2_5].x = 31;	}
		else								{	cnt[CONT_F2_5].x = 27;	}
		cnt[CONT_F2_5].y = 18;
		conText.x = centerX + t2x * span + 2;
		conText.y = centerY - t2y * span - 32;
		conText.visible = true;
	}
	catch(e)
	{
		alert("drawCont:" + e.toString());
	}
}

//	+--------------+
//	| 式や値の表示 |
//	+--------------+
function drawFormula()
{
	try
	{
		{
			var str = "";
			str += "\\small{" + "y=" + aNum + "^x" + "}";
			changeMathJax("form0", str, false);
		}
		{
			var str = "";
			str += "\\small{" + "y=(\\frac{1}{" + aNum + "})^x" + "}";
			changeMathJax("form1", str, false);
		}
		{
			var str = "";
			str += "\\small{" + "(x, " + aNum + "^x)" + "}";
			changeMathJax("form2", str, false);
		}
		{
			var str = "";
			str += "\\small{" + "(x, (\\frac{1}{" + aNum + "})^x)" + "}";
			changeMathJax("form3", str, false);
		}
		{
			var str = "";
			str += "\\small{" + "(-x, (\\frac{1}{" + aNum + "})^{-x})" + "}";
			changeMathJax("form4", str, false);
		}
	}
	catch(e)
	{
		alert("drawFormula:" + e.toString());
	}
}

//	+----------+
//	| 式の編集 |
//	+----------+
function editForm(a,b,c,f)
{
	try
	{
		var str = "";
		switch( a )
		{
			case 0:
				break;
			case -1:
				str += "<span class='uTimes'>-</span><span class='times'>x</span>";
				break;
			case 1:
				str += "<span class='times'>x</span>";
				break;
			default:
				str += "</span><span class='uTimes'>" + a + "</span><span class='times'>x</span>";
				break;
		}
		
		switch( b )
		{
			case 0:
				break;
			case -1:
				if ( a == 0 )	{	str += "<span class='times'>y</span>";											}
				else			{	str += "<span class='uTimes'> - </span><span class='times'>y</span>";		}
				break;
			case 1:
				if ( a == 0 )	{	str += "<span class='times'>y</span>";											}
				else			{	str += "<span class='uTimes'> + </span><span class='times'>y</span>";		}
				break;
			default:
				if ( a == 0 )
				{
					str += "<span class='uTimes'>" + b + "</span><span class='times'>y</span>";
				}
				else
				{
					if ( b > 0 )	{	str += "<span class='uTimes'> + " + Math.abs(b) + "</span><span class='times'>y</span>";	}
					else			{	str += "<span class='uTimes'> - " + Math.abs(b) + "</span><span class='times'>y</span>";	}
				}
				break;
		}
		switch( f )
		{
			case "0":
				break;
			case "1":
				if ( c > 0 )	{	str += "<span class='uTimes'> + " + Math.abs(c) + "</span>";	}
				if ( c < 0 )	{	str += "<span class='uTimes'> - " + Math.abs(c) + "</span>";	}
				break;
			default:
				str += "</span><span class='uTimes'> " + f + " " + -c + "</span>";
				break;
		}
		return str;
	}
	catch(e)
	{
		alert("editForm:" + e.toString());
	}
}

//	+------------+
//	| 式の編集２ |
//	+------------+
function editForm2(a,b,c)
{
	try
	{
		var str = "y=";
		if ( a == 0 )
		{
			str += c;
		}
		else
		{
			if ( b == 0 )
			{
				str += "0";
			}
			else
			{
				if ( b >= 0 )
				{
					var ab = Math.round( -a / b * 100 ) / 100;
					var cb = Math.round( -c / b * 100 ) / 100;
					if ( ab == 1 || ab == -1 )
					{
						if ( ab == 1 )	{	str += "x";		}
						else			{	str += "-x";	}
					}
					else
					{
						str += ab + "x";
					}
					if ( cb > 0 )	{	str += "+" + Math.abs( cb );	}
					if ( cb < 0 )	{	str += "-" + Math.abs( cb );	}
				}
				else
				{
					var ab = Math.round( a / -b * 100 ) / 100;
					var cb = Math.round( c / -b * 100 ) / 100;
					if ( ab == 1 || ab == -1 )
					{
						if ( ab == 1 )	{	str += "x";		}
						else			{	str += "-x";	}
					}
					else
					{
						str += ab + "x";
					}
					if ( cb > 0 )	{	str += "+" + Math.abs( cb );	}
					if ( cb < 0 )	{	str += "-" + Math.abs( cb );	}
				}
			}
		}
		return str;
	}
	catch(e)
	{
		alert("editForm2:" + e.toString());
	}
}

//	+------------+
//	| 式の編集３ |
//	+------------+
function editForm3(a,b,c,f)
{
	try
	{
		var str;
		switch( a )
		{
			case -1:
				str = "-x";
				break;
			case 1:
				str = "x";
				break;
			default:
				str = a + "x";
				break;
		}
		
		switch( b )
		{
			case -1:
				str += "-y";
				break;
			case 1:
				str += "+y";
				break;
			default:
				if ( b >= 0 )	{	str = "+" + b + "y";	}
				else			{	str = b + "y";			}
				break;
		}
		switch( f )
		{
			case "none":
				break;
			case "=0":
			case ">0":
			case "<0":
			case "≧0":
			case "≦0":
				if ( c > 0 )	{	str += "+" + Math.abs(c) + f;	}
				if ( c < 0 )	{	str += "-" + Math.abs(c) + f;	}
				if ( c == 0 )	{	str += f;	}
				break;
			case "1":
				if ( c > 0 )	{	str += "+" + Math.abs(c);	}
				if ( c < 0 )	{	str += "-" + Math.abs(c);	}
				break;
			default:
				str += + f + Math.abs(c);
				break;
		}
		return str;
	}
	catch(e)
	{
		alert("editForm3:" + e.toString());
	}
}

//	+--------------+
//	| ドットの表示 |
//	+--------------+
function drawDot(dot,x,y,color,alpha)
{
	try
	{
		var col = "rgba(0,0,0," + alpha + ")";
		switch( color )
		{
			case "gray":
				col = "rgba(32,32,32," + alpha + ")";
				break;
			case "blue":
				col = "rgba(0,122,197," + alpha + ")";
				break;
			case "red":
				col = "rgba(255,0,0," + alpha + ")";
				break;
			case "orange":
				col = "rgba(255,127,0," + alpha + ")";
				break;
		}
		
		var x = centerX + x * span;
		var y = centerY - y * span;
		dot.graphics.setStrokeStyle(1);
		dot.graphics.beginStroke("rgba(255, 255, 255, 0.02)");
		dot.graphics.beginFill(col);
		dot.graphics.drawCircle(x, y, 5);
		dot.graphics.beginFill("rgba(255, 255, 255, 0.02)");
		dot.graphics.drawCircle(x, y, 15);
		dot.graphics.endFill();
		dot.graphics.endStroke();
	}
	catch(e)
	{
		alert("drawDot:" + e.toString());
	}
}

//	+----------+
//	| 円の表示 |
//	+----------+
function drawRing(circle, x, y, r, col, alpha, fill)
{
	try
	{
		circle.graphics.setStrokeStyle(1);
		// 色
		var color;
		switch( col )
		{
			case "white":
				color = "rgba( 255, 255, 255, " + alpha + " )";
				break;
			case "blue":
				color = "rgba( 0, 165, 199, " + alpha + " )";
				break;
			case "red":
				color = "rgba( 255, 0, 0, " + alpha + " )";
				break;
			default:
				color = "rgba( 0, 0, 0, " + alpha + " )";
				break;
		}
		circle.graphics.beginStroke( color );
		if ( fill )		{	circle.graphics.beginFill( color );		}
		circle.graphics.drawCircle( centerX + x * span, centerY - y * span, r * span );
		if ( fill )		{	circle.graphics.endFill();		}
		circle.graphics.endStroke();
	}
	catch(e)
	{
		alert("drawRing:" + e.toString());
	}
}


//	+------------+
//	| 円の表示２ |
//	+------------+
function drawRing2(circle, x, y, r, col1, col2, alpha, fill)
{
	try
	{
		circle.graphics.setStrokeStyle(1);
		// 色
		var color;
		switch( col1 )
		{
			case "white":
				color = "rgba( 255, 255, 255, " + alpha + " )";
				break;
			case "blue":
				color = "rgba( 0, 165, 199, " + alpha + " )";
				break;
			case "red":
				color = "rgba( 255, 0, 0, " + alpha + " )";
				break;
			default:
				color = "rgba( 0, 0, 0, " + alpha + " )";
				break;
		}
		var fillColor;
		switch( col2 )
		{
			case "white":
				fillColor = "rgba( 255, 255, 255, " + alpha + " )";
				break;
			case "blue":
				fillColor = "rgba( 0, 165, 199, " + alpha + " )";
				break;
			case "red":
				fillColor = "rgba( 255, 0, 0, " + alpha + " )";
				break;
			default:
				fillColor = "rgba( 0, 0, 0, " + alpha + " )";
				break;
		}
		circle.graphics.beginStroke( color );
		if ( fill )		{	circle.graphics.beginFill( fillColor );		}
		circle.graphics.drawCircle( centerX + x * span, centerY - y * span, r * span );
		if ( fill )		{	circle.graphics.endFill();		}
		circle.graphics.endStroke();
	}
	catch(e)
	{
		alert("drawRing2:" + e.toString());
	}
}

//	+--------------+
//	| 直線の表示１ |
//	+--------------+
function drawLine_1(line, a, b, c, col, alpha)
{
	try
	{
		// 傾き(軸の方向注意)
		var pA = a / b;
		
		// 切片(軸の方向注意)
		var pB = c / b;
		
		line.graphics.setStrokeStyle(1);
		
		// 色
		switch( col )
		{
			case "blue":
				line.graphics.beginStroke("rgba( 0, 165, 199, " + alpha + ")");
				break;
			case "red":
				line.graphics.beginStroke("rgba( 255, 0, 0, " + alpha + ")");
				break;
			default:
				line.graphics.beginStroke("rgba( 0, 0, 0, " + alpha + ")");
				break;
		}
		
		// 縦の線
		if ( b == 0 )
		{
			line.graphics.moveTo(0, -cH);
			line.graphics.lineTo(0, cH);
			line.x = cW/2 + (-c/a) * span;
			line.y = cH/2;
			line.graphics.endStroke();
			line.graphics.setStrokeStyle(20);
			line.graphics.beginStroke("rgba( 255, 255, 255, 0.02 )");
			line.graphics.beginFill("rgba( 255, 255, 255, 0.02 )");
			line.x = cW/2 + (-c/a) * span;
			line.y = cH/2;
			line.graphics.endFill();
		}
		// 横の線
		else if ( a == 0 )
		{
			line.graphics.moveTo(-cW, 0);
			line.graphics.lineTo(cW, 0);
			line.x = cW/2;
			line.y = cH/2 + pB * span;
			line.graphics.endStroke();
			line.graphics.setStrokeStyle(20);
			line.graphics.beginStroke("rgba( 255, 255, 255, 0.02 )");
			line.graphics.beginFill("rgba( 255, 255, 255, 0.02 )");
			line.graphics.moveTo(-cW, 0);
			line.graphics.lineTo(cW, 0);
			line.graphics.endFill();
		}
		else
		{
			line.graphics.moveTo(-cH/ pA, -cH);
			line.graphics.lineTo(cH/ pA, cH);
			line.x = cW/2;
			line.y = cH/2 + pB  * span;
			line.graphics.endStroke();
			line.graphics.setStrokeStyle(20);
			line.graphics.beginStroke("rgba( 255, 255, 255, 0.02 )");
			line.graphics.beginFill("rgba( 255, 255, 255, 0.02 )");
			line.graphics.moveTo(-cH/ pA, -cH);
			line.graphics.lineTo(cH/ pA, cH);
			line.graphics.endFill();
			
		}
		
		line.graphics.endStroke();
		
	}
	catch(e)
	{
		alert("drawLineHandler:" + e.toString());
	}
}

//	+--------------+
//	| 直線の表示２ |
//	+--------------+
function drawLine_2(line,xx1,yy1,xx2,yy2,col,alpha)
{
	try
	{
		var k = ( x2 - x1 ) / ( y2 - y1 ) * 2000;
		line.graphics.setStrokeStyle(1);
		switch( col )
		{
			case "blue":
				line.graphics.beginStroke("rgba( 0, 165, 199, " + alpha + ")");
				break;
			case "red":
				line.graphics.beginStroke("rgba( 255, 0, 0, " + alpha + ")");
				break;
			default:
				line.graphics.beginStroke("rgba( 0, 0, 0, " + alpha + ")");
				break;
		}
		line.graphics.moveTo( centerX + xx1 * span + k, centerY - yy1 * span + 2000);
		line.graphics.lineTo( centerX + xx2 * span - k, centerY - yy2 * span - 2000);
		line.graphics.endStroke();
		
	}
	catch(e)
	{
		alert("drawLineHandler:" + e.toString());
	}
}

//	+--------------+
//	| 直線の表示３ |
//	+--------------+
function drawLine_3(line,xx1,yy1,xx2,yy2,col,alpha)
{
	try
	{
		line.graphics.setStrokeStyle(1);
		switch( col )
		{
			case "blue":
				line.graphics.beginStroke("rgba( 0, 165, 199, " + alpha + ")");
				break;
			case "red":
				line.graphics.beginStroke("rgba( 255, 0, 0, " + alpha + ")");
				break;
			default:
				line.graphics.beginStroke("rgba( 0, 0, 0, " + alpha + ")");
				break;
		}
		line.graphics.moveTo( centerX + xx1 * span, centerY - yy1 * span);
		line.graphics.lineTo( centerX + xx2 * span, centerY - yy2 * span);
		line.graphics.endStroke();
		
	}
	catch(e)
	{
		alert("drawLineHandler:" + e.toString());
	}
}

//	+----------------+
//	| 座標破線の表示 |
//	+----------------+
function drawDotLine(line,x,y,col,alpha)
{
	try
	{
		line.graphics.setStrokeStyle(1);
		var color;
		switch( col )
		{
			case "blue":
				color = "rgba( 0, 165, 199, " + alpha + " )";
				break;
			case "red":
				color = "rgba( 255, 0, 0, " + alpha + " )";
				break;
			default:
				color = "rgba( 0, 0, 0, " + alpha + " )";
				break;
		}
		line.graphics.beginStroke( color );
		line.graphics.setStrokeDash([5, 5], 0);
		line.graphics.moveTo( centerX + x * span, centerY );
		line.graphics.lineTo( centerX + x * span, centerY - y * span );
		line.graphics.lineTo( centerX, centerY - y * span );
		line.graphics.endStroke();
	}
	catch(e)
	{
		alert("drawDotLine:" + e.toString());
	}
}

//	+--------------+
//	| 四角形の表示 |
//	+--------------+
function drawSquare(line,x1,y1,x2,y2,col,alpha,fill)
{
	try
	{
		line.graphics.setStrokeStyle(1);
		var color;
		switch( col )
		{
			case "blue":
				color = "rgba( 0, 165, 199, " + alpha + " )";
				break;
			case "red":
				color = "rgba( 255, 0, 0, " + alpha + " )";
				break;
			default:
				color = "rgba( 0, 0, 0, " + alpha + " )";
				break;
		}
		line.graphics.beginStroke( color );
		if ( fill )		{	line.graphics.beginFill( color );		}
		line.graphics.moveTo( centerX + x1 * span, centerY - y1 * span );
		line.graphics.lineTo( centerX + x2 * span, centerY - y1 * span );
		line.graphics.lineTo( centerX + x2 * span, centerY - y2 * span );
		line.graphics.lineTo( centerX + x1 * span, centerY - y2 * span );
		line.graphics.lineTo( centerX + x1 * span, centerY - y1 * span );
		if ( fill )		{	line.graphics.endFill();		}
		line.graphics.endStroke();
	}
	catch(e)
	{
		alert("drawSquare:" + e.toString());
	}
}

//	+------------+
//	| 矩形の表示 |
//	+------------+
function drawBox(line,x1,y1,x2,y2,x3,y3,x4,y4,col,alpha,fill)
{
	try
	{
		line.graphics.setStrokeStyle(1);
		var color;
		switch( col )
		{
			case "blue":
				color = "rgba( 0, 165, 199, " + alpha + " )";
				break;
			case "red":
				color = "rgba( 255, 0, 0, " + alpha + " )";
				break;
			default:
				color = "rgba( 0, 0, 0, " + alpha + " )";
				break;
		}
		line.graphics.beginStroke( color );
		if ( fill )		{	line.graphics.beginFill( color );		}
		line.graphics.moveTo( centerX + x1 * span, centerY - y1 * span );
		line.graphics.lineTo( centerX + x2 * span, centerY - y2 * span );
		line.graphics.lineTo( centerX + x3 * span, centerY - y3 * span );
		line.graphics.lineTo( centerX + x4 * span, centerY - y4 * span );
		line.graphics.lineTo( centerX + x1 * span, centerY - y1 * span );
		if ( fill )		{	line.graphics.endFill();		}
		line.graphics.endStroke();
	}
	catch(e)
	{
		alert("drawBox:" + e.toString());
	}
}

//	+--------------+
//	| 三角形の表示 |
//	+--------------+
function drawTriangle(line,x1,y1,x2,y2,x3,y3,col,alpha,fill)
{
	try
	{
		line.graphics.setStrokeStyle(1);
		var color;
		switch( col )
		{
			case "blue":
				color = "rgba( 0, 165, 199, " + alpha + " )";
				break;
			case "red":
				color = "rgba( 255, 0, 0, " + alpha + " )";
				break;
			default:
				color = "rgba( 0, 0, 0, " + alpha + " )";
				break;
		}
		line.graphics.beginStroke( color );
		if ( fill )		{	line.graphics.beginFill( color );		}
		line.graphics.moveTo( centerX + x1 * span, centerY - y1 * span );
		line.graphics.lineTo( centerX + x2 * span, centerY - y2 * span );
		line.graphics.lineTo( centerX + x3 * span, centerY - y3 * span );
		line.graphics.lineTo( centerX + x1 * span, centerY - y1 * span );
		if ( fill )		{	line.graphics.endFill();		}
		line.graphics.endStroke();
	}
	catch(e)
	{
		alert("drawTriangle:" + e.toString());
	}
}

//	+--------------+
//	| 等長線の表示 |
//	+--------------+
function drawEqlenLine(line,x1,y1,x2,y2,pos,col,alpha)
{
	try
	{
		x1 = centerX + x1 * span;
		y1 = centerY - y1 * span;
		x2 = centerX + x2 * span;
		y2 = centerY - y2 * span;
		var t =  Math.atan2( ( x2 - x1 ) , ( y2 - y1 ) );
		var xx = Math.cos(t) * 5;
		var yy = Math.sin(t) * 5;
		line.graphics.setStrokeStyle(1);
		switch( col )
		{
			case "blue":
				line.graphics.beginStroke("rgba( 0, 165, 199, " + alpha + ")");
				break;
			case "red":
				line.graphics.beginStroke("rgba( 255, 0, 0, " + alpha + ")");
				break;
			default:
				line.graphics.beginStroke("rgba( 0, 0, 0, " + alpha + ")");
				break;
		}
		var bX1 = x2 + ( x1 - x2 ) * pos;
		var bY1 = y2 + ( y1 - y2 ) * pos;
		line.graphics.moveTo( bX1 + xx, bY1 - yy );
		line.graphics.lineTo( bX1 - xx, bY1 + yy );
		line.graphics.endStroke();
	}
	catch(e)
	{
		alert("drawEqlenLine:" + e.toString());
	}
}

//	+----------+
//	| 座標表示 |
//	+----------+
function drawPosText(text1,text2)
{
	var x = text1.text;
	var y = text2.text;
	text1.x = centerX + x * span - 4;
	if ( y >= 0 )
	{
		text1.y = centerY;
	}
	else
	{
		text1.y = centerY - 20;
	}
	if ( x >= 0 )
	{
		text2.textAlign = "right";
		text2.x = centerX - 4;
	}
	else
	{
		text2.textAlign = "left";
		text2.x = centerX + 4;
	}
	text2.y = centerY - y * span - 10;
}

//	+------------+
//	| 座標表示２ |
//	+------------+
function drawPosText2(text1,text2)
{
	var x = text1.text;
	var y = text2.text;
	if ( x >= 0 )
	{
		text1.x = centerX + x * span + 4;
	}
	else
	{
		text1.x = centerX + x * span - 18;
	}
	text1.y = centerY;
	
	text2.textAlign = "right";
	text2.x = centerX - 4;
	if ( y >= 0 )
	{
		text2.y = centerY - y * span - 20;
	}
	else
	{
		text2.y = centerY - y * span;
	}
}

//	+--------------+
//	| 計算処理サブ |
//	+--------------+
function calcLine(x1,y1,x2,y2)
{
	
	var a = ( x2-x1 ) / ( y2-y1 );
	var b = 1;
	var c = y2;
	return [ {a:a,b:b,c:c} ];
}

function getX(a,b,c,y)
{
	return -( y * b + c ) / a;
}

function getY(a,b,c,x)
{
	return -( x * a + c ) / b;
}

// ２直線の交点
function cpt(a1,b1,c1,a2,b2,c2)
{
	var a = a1 / b1;
	var b = c1 / b1;
	var c = a2 / b2;
	var d = c2 / b2;
	var x = ( d - b ) / ( a - c );
	var y = -( a * d - b * c ) / ( a - c );
	x = Math.round( x * 100 ) / 100;
	y = Math.round( y * 100 ) / 100;
	return [{x:x,y:y}];
}

// 円と直線の交点
function cli(a,b,c,x1,y1,r)
{
	var l = a*a+b*b;
	var k = a*x1+b*y1+c;
	var d = l*r*r-k*k;
	if(d>0){
		var ds = Math.sqrt(d);
		var apl = a/l;
		var bpl = b/l;
		var xc = x1-apl*k;
		var yc = y1-bpl*k;
		var xd = bpl*ds;
		var yd = apl*ds;
		return [
			{x:xc-xd,y:yc+yd},
			{x:xc+xd,y:yc-yd}
		];
	}else if(d==0){
		return [{x:x1-a*k/l,y:y1-b*k/l}];
	}else{
		return [];
	}
}
// 円と円の交点
function cci(x1,y1,r1,x2,y2,r2)
{
	var a = x1-x2;
	var b = y1-y2;
	return cli(a,b,0.5*((r1-r2)*(r1+r2)-a*(x1+x2)-b*(y1+y2)),x1,y1,r1);
}

// 円の半径
function calcRad(x,y,l,m,n)
{
	var xx = x + l / 2;
	var yy = y + m / 2;
	var rad = ( l * l + m * m ) / 4 + n;
	var r = Math.sqrt( rad );
	return	[ {x:xx,y:yy,rad:rad,r:r} ];
}

//	+----------+
//	| 値の入力 |
//	+----------+
function changeDataHandler(e)
{
	try
	{
		switch( e.currentTarget.id )
		{
			case "upBtn0":
				if ( slider.prev + stepSize <= slider.max )
				{
					slider.prev += stepSize;
					document.getElementById('xNum').innerHTML = Math.round( slider.prev * 100 ) / 100;
					slider.prev = Math.round( slider.prev * 100 ) / 100;
				}
				break;
			case "downBtn0":
				if ( slider.prev - stepSize >= slider.min )
				{
					slider.prev -= stepSize;
					document.getElementById('xNum').innerHTML = Math.round( slider.prev * 100 ) / 100;
					slider.prev = Math.round( slider.prev * 100 ) / 100;
				}
				break;
		}
		calcData();
		drawFormula();
		drawShape();
		drawText();
		slider.changeSliderPoint();
		cs.update();
	}
	catch(e)
	{
		alert("changeDataHandler:" + e.toString());
	}
}

// +----------------------------+
// | 式の値変更入力画面オープン |
// +----------------------------+
function openOptionHandler(e)
{
	try
	{
		if(animeFlag == false)
		{
			//式の値を設定
			document.getElementById('optionBlock0').style.display = "none";
			optName = e.currentTarget.id;
			switch ( optName )
			{
				case "optionBtn0":
					document.getElementById('text0_0').value = aNum;
					document.getElementById('optionBlock0').style.display = "";
					break;
			}
			showModal('optionBlock');
		}
	}
	catch(e)
	{
		alert('openOptionHandler:' + e.toString());
	}
}

// +----------------+
// | 式の値変更入力 |
// +----------------+
function changeFormulaHandler(e)
{
	try
	{
		var num;
		switch(e.target.id)
		{
			case "upBtn0_0":
				num = parseFloat(document.getElementById("text0_0").value);
				num += stepSize;
				num = Math.round( num * 100 ) / 100;
				document.getElementById("text0_0").value = num;
				break;
			
			case "downBtn0_0":
				num = parseFloat(document.getElementById("text0_0").value);
				num -= stepSize;
				num = Math.round( num * 100 ) / 100;
				document.getElementById("text0_0").value = num;
				break;
			
		}
	}
	catch(e)
	{
		alert("changeFormulaHandler:" + e.toString());
	}
}

// +----------------------------+
// | 式の値変更入力画面クローズ |
// +----------------------------+
function closeOptionHandler(e)
{
	try
	{
		switch ( optName )
		{
			case "optionBtn0":
				aNum = parseFloat(document.getElementById("text0_0").value);
				break;
		}
		optName = "";
		
		calcData();
		drawFormula();
		drawShape();
		drawText();
		cs.update();
		closeModal();
	}
	catch(e)
	{
		alert("closeOptionHandler:" + e.toString());
	}
}

//	+------------------------------+
//	| チェックボックスのオン・オフ |
//	+------------------------------+
function changeCheckHandler(e)
{
	try
	{
		calcData();
		drawFormula();
		drawShape();
		drawText();
		cs.update();
	}
	catch(e)
	{
		alert("changeCheckHandler:" + e.toString());
	}
}

//	+----------------------+
//	| 刻み幅の設定画面表示 |
//	+----------------------+
function openMenuBalloonHandler(e)
{
	try
	{
		var inner;
		var data;
		if ( e.currentTarget.id == "stepText" )
		{
			inner = [0.1, 0.2, 0.5, 1, 2, 5, 10];
			data = [0.1, 0.2, 0.5, 1, 2, 5, 10];
		}
		openSelectBalloon("selectBalloon_menu", "menuBlock", e.currentTarget.id, inner, data, changeStepSize);
	}
	catch(e)
	{
		alert("openMenuBalloonHandler:"+e.toString());
	}
}
//	+--------------+
//	| 刻み幅の変更 |
//	+--------------+
function changeStepSize(id, num)
{
	try
	{
		stepSize = num;
		slider.span = num;
		
		// 設定した刻み幅の倍数に変更
		var n;
		n = slider.prev;
		n = Math.round(n/num) * num;
		n = Math.round(n * 100)/100;
		document.getElementById("xNum").innerHTML = n;
		slider.prev = n;
		
		slider.changeSliderLine();
		slider.changeSliderPoint();
		slider.changeSliderControl();

		calcData();
		drawFormula();
		drawShape();
		drawText();
		cs.update();
	}
	catch(e)
	{
		alert("changeStepSize:" + e.toString());
	}
}

//	+------------------+
//	| 点のドラッグ開始 |
//	+------------------+
function dotDragStart(e)
{
	try
	{
		if ( dFlag )
		{
			dFlag = false;
			prevX = e.stageX;
			prevY = e.stageY;
			
			e.currentTarget.addEventListener("pressmove", dotDragMove);
			e.currentTarget.addEventListener("pressup", dotDragStop);
			e.currentTarget.addEventListener("mouseup", dotDragStop);
			e.currentTarget.addEventListener("mouseout", dotDragStop);
		}
	}
	catch(e)
	{
		alert("dotDragStart:" + e.toString());
	}
}

//	+--------------+
//	| 点のドラッグ |
//	+--------------+
function dotDragMove(e)
{
	try
	{
		var x = e.stageX - prevX;
		var y = e.stageY - prevY;
		var size = 0.01;
		
		if ( Math.abs( x ) > 1 || Math.abs( y ) > 1 )
		{
			prevX = e.stageX;
			prevY = e.stageY;
			var numX = ( e.stageX - centerX ) / span;
			var numY = -( e.stageY - centerY ) / span;
			numX = Math.round( numX / size ) * size;
			numY = Math.round( numY / size ) * size;
			numX = Math.round( numX * 10 ) / 10;
			numY = Math.round( numY * 10 ) / 10;
			switch( e.currentTarget.name )
			{
				case "dotA":
					ax = numX;
					ay = numY;
					break;
				case "dotP":
					break;
			}
		}
		calcData();
		drawFormula();
		drawShape();
		drawText();
		cs.update();
	}
	catch(e)
	{
		alert("dotDragMove:" + e.toString());
	}
}

//	+------------------+
//	| 点のドラッグ終了 |
//	+------------------+
function dotDragStop(e)
{
	try
	{
		dFlag = true;
		
		calcData();
		drawFormula();
		drawShape();
		drawText();
		cs.update();
		
		e.currentTarget.removeEventListener("pressmove", dotDragMove);
		e.currentTarget.removeEventListener("pressup", dotDragMove);
		e.currentTarget.removeEventListener("mouseup", dotDragMove);
		e.currentTarget.removeEventListener("mouseout", dotDragMove);
	}
	catch(e)
	{
		alert("dotDragStop:" + e.toString());
	}
}

//	+------------------+
//	| 線のドラッグ開始 |
//	+------------------+
function lineDragStart(e)
{
	try
	{
		if ( dFlag )
		{
			dFlag = false;
			prevX = e.stageX;
			prevY = e.stageY;
			
			shp[SHAPE_LINE_K].graphics.clear();
			drawLine_1( shp[SHAPE_LINE_K], 1, 1, -slider.prev, "red", 1 );
			cs.update();
			
			e.currentTarget.addEventListener("pressmove", lineDragMove);
			e.currentTarget.addEventListener("pressup",lineDragStop);
			e.currentTarget.addEventListener("mouseup", lineDragStop);
			e.currentTarget.addEventListener("mouseout", lineDragStop);
		}
	}
	catch(e)
	{
		alert("lineDragStart:" + e.toString());
	}
}

//	+--------------+
//	| 線のドラッグ |
//	+--------------+
function lineDragMove(e)
{
	try
	{
		var x = e.stageX - prevX;
		var y = e.stageY - prevY;
		var size = 0.1;
		
		if ( Math.abs( x ) > 1 )
		{
			prevX = e.stageX;
			prevY = e.stageY;
			if ( x > 0 )	{	slider.prev += size;	}
			if ( x < 0 )	{	slider.prev -= size;	}
			slider.prev = Math.round( slider.prev * 100 ) / 100;
			shp[SHAPE_LINE_K].graphics.clear();
			drawLine_1( shp[SHAPE_LINE_K], 1, 1, -slider.prev, "red", 1 );
			txt[TEXT_K].text = "k=" + slider.prev;
			txt[TEXT_K].x = centerX + slider.prev * span + 20;
			txt[TEXT_K].y = centerY + span;
			txt[TEXT_K].color = "#00A5C7";
			cs.update();
		}
		
	}
	catch(e)
	{
		alert("lineDragMove:" + e.toString());
	}
}
//	+------------------+
//	| 線のドラッグ終了 |
//	+------------------+
function lineDragStop(e)
{
	try
	{
	
		shp[SHAPE_LINE_K].graphics.clear();
		drawLine_1( shp[SHAPE_LINE_K], 1, 1, -slider.prev, "blue", 1 );
		cs.update();
		dFlag = true;
		
		e.currentTarget.removeEventListener("pressmove", dotDragMove);
		e.currentTarget.removeEventListener("pressup", dotDragMove);
		e.currentTarget.removeEventListener("mouseup", dotDragMove);
		e.currentTarget.removeEventListener("mouseout", dotDragMove);
	}
	catch(e)
	{
		alert("lineDragStop:" + e.toString());
	}
}

//	+--------------------------+
//	| キャンバスのドラッグ開始 |
//	+--------------------------+
function canvasDragStart(e)
{
	if(dFlag)
	{
		prevX = e.stageX;
		prevY = e.stageY;
		
		if(ictMode)
		{
			$(window).on("touchend mouseup", dragStop);
		}
		else if(mFlag)
		{
			document.addEventListener('touchend', dragStop);
		}
		else
		{
			document.addEventListener('mouseup', dragStop);
		}
		
		e.currentTarget.addEventListener("pressmove", canvasDragMove);
		e.currentTarget.addEventListener("pressup", canvasDragStop);
	}
}

//	+----------------------+
//	| キャンバスのドラッグ |
//	+----------------------+
function canvasDragMove(e)
{
	try
	{
		var p = $("#graphCanvas").position();
		
		//座標の変化量
		var sX;
		var sY;
		
		if(cScale >= 1)
		{
			sX = e.stageX - prevX;
			sY = e.stageY - prevY;
		}
		else
		{
			sX = (e.stageX - prevX) * cScale;
			sY = (e.stageY - prevY) * cScale;
		}
		
		//移動限界
		var limitX = cW * 1/3 - cW * cScale;
		var limitY = cH * 1/3 - cH * cScale;
		
		//Xの差分移動
		if(p.left + sX >= 0)
		{
			document.getElementById("graphCanvas").style.left = "0px";
			
			prevX = e.stageX;
		}
		else if(p.left + sX <= limitX)
		{
			document.getElementById("graphCanvas").style.left = limitX + "px";
			
			prevX = e.stageX;
		}
		else
		{
			document.getElementById("graphCanvas").style.left = (p.left + sX) + "px";
		}
		
		//Yの差分移動
		if(p.top + sY >= 0)
		{
			document.getElementById("graphCanvas").style.top = "0px";
			
			prevY = e.stageY;
		}
		else if(p.top + sY <= limitY)
		{
			document.getElementById("graphCanvas").style.top = limitY + "px";
			
			prevY = e.stageY;
		}
		else
		{
			document.getElementById("graphCanvas").style.top = (p.top + sY) + "px";
		}
		
		changeAxisPositionHandler();
		cs.update();
	}
	catch(e)
	{
		alert("canvasDragMove:" + e.toString());
	}
	
}

//	+--------------------------+
//	| キャンバスのドラッグ終了 |
//	+--------------------------+
function canvasDragStop(e)
{
	e.currentTarget.removeEventListener("pressmove", canvasDragMove);
	e.currentTarget.removeEventListener("pressup", canvasDragStop);
}

//	+--------------------------+
//	| キャンバスのドラッグ終了 |
//	+--------------------------+
function dragStop(e)
{
	try
	{
		if(ictMode)
		{
			$(window).off("touchend mouseup", dragStop);
		}
		else if(mFlag)
		{
			document.removeEventListener('touchend', dragStop);
		}
		else
		{
			document.removeEventListener('mouseup', dragStop);
		}
	}
	catch(e)
	{
		alert(e.toString());	
	}
}

//	+----------------------------+
//	| オプション画面のスクロール |
//	+----------------------------+
function closeInnerBalloonHandler(e)
{
	try
	{
		// 刻み幅入力画面が開かれていたら閉じる
		if ( document.getElementById("selectBalloon_menu").style.display != "none" )
		{
			closeSelectBalloon();
		}
	}
	catch(e)
	{
		alert("closeInnerBalloonHandler:" + e.toString());
	}
}

//	+--------------+
//	| スケール変更 |
//	+--------------+
function changeGraphScale(sX, sY)
{
	try
	{
		base.graphics.clear();
		
		base.graphics.setStrokeStyle(1);
		base.graphics.beginStroke("#000000");
		
		//x軸
		base.graphics.moveTo(0, cH/2);
		base.graphics.lineTo(cW, cH/2);
		
		//y軸
		base.graphics.moveTo(cW/2, 0);
		base.graphics.lineTo(cW/2, cH);
		
		var i;
		
		var spanX;
		var spanY;
		
		//x軸の目盛
		if(sX != null)
		{
			var spanX = span * sX;
			for(i = cW/2-spanX; i>0; i=i-spanX)
			{
				base.graphics.moveTo(i, cH/2-5);
				base.graphics.lineTo(i, cH/2+5);
			}
			
			for(i = cW/2+spanX; i<cW; i=i+spanX)
			{
				base.graphics.moveTo(i, cH/2-5);
				base.graphics.lineTo(i, cH/2+5);
			}
		}
		
		
		//y軸の目盛
		if(sY != null)
		{
			spanY = span * sY;
			for(i = cH/2-spanY; i>0; i=i-spanY)
			{
				base.graphics.moveTo(cW/2-5, i);
				base.graphics.lineTo(cW/2+5, i);
			}
			
			for(i = cH/2+spanY; i<cH; i=i+spanY)
			{
				base.graphics.moveTo(cW/2-5, i);
				base.graphics.lineTo(cW/2+5, i);
			}
		}
	}
	catch(e)
	{
		alert("changeGraphScale:" + e.toString());
	}
}

//	+--------------+
//	| グリッド変更 |
//	+--------------+
function changeGraphGrid(gX, gY)
{
	try
	{
		grid.graphics.clear();
		grid.graphics.setStrokeStyle(0.5);
		grid.graphics.beginStroke("#00A0FF");
		
		var i;
		
		var spanX;
		var spanY;
		
		//x軸の線
		if(gX != null)
		{
			var spanX = span * gX;
			for(i = cW/2-spanX; i>0; i=i-spanX)
			{
				grid.graphics.moveTo(i, 0);
				grid.graphics.lineTo(i, cH);
			}
			
			for(i = cW/2+spanX; i<cW; i=i+spanX)
			{
				grid.graphics.moveTo(i, 0);
				grid.graphics.lineTo(i, cH);
			}
		}
		
		
		//y軸の線
		if(gY != null)
		{
			spanY = span * gY;
			for(i = cH/2-spanY; i>0; i=i-spanY)
			{
				grid.graphics.moveTo(0, i);
				grid.graphics.lineTo(cW, i);
			}
			
			for(i = cH/2+spanY; i<cH; i=i+spanY)
			{
				grid.graphics.moveTo(0, i);
				grid.graphics.lineTo(cW, i);
			}
		}
	}
	catch(e)
	{
		alert('changeGraphGrid:' + e.toString());
	}
}

//	+----------+
//	| 状態保存 |
//	+----------+
function saveContent()
{
	var array = [];
	try
	{
		
		var xNum = document.getElementById("xNum").innerHTML;
		array[0] = { stepSize:stepSize };
		array[1] = { aNum:aNum, xNum:xNum }
		
		var chk0 = document.getElementById("check0").checked;
		var chk1 = document.getElementById("check1").checked;
		var chk2 = document.getElementById("check2").checked;
		var chk3 = document.getElementById("check3").checked;
		var chk4 = document.getElementById("check4").checked;
		array[2] = { chk0:chk0, chk1:chk1, chk2:chk2, chk3:chk3, chk4:chk4 };
		array[3] = { recData:recData };
	}
	catch(e)
	{
		alert("saveContent:" + e.toString());
	}
	return array;
}

//	+----------+
//	| 状態読込 |
//	+----------+
function loadContent(array)
{
	try
	{
		stepSize = array[0].stepSize;
		
		aNum = array[1].aNum;
		document.getElementById("xNum").innerHTML = array[1].xNum;
		
		document.getElementById("check0").checked = array[2].chk0;
		document.getElementById("check1").checked = array[2].chk1;
		document.getElementById("check2").checked = array[2].chk2;
		document.getElementById("check3").checked = array[2].chk3;
		document.getElementById("check4").checked = array[2].chk4;
		
		resetCapture();
		for(i = 0; i < array[3].recData.length; ++i)
		{
			createcaptureData(array[3].recData[i]);
		}
		
		// 軸表示
		drawBaseLine();
		changeAxisPositionHandler();
		
		// 計算処理
		calcData();
		
		// 式の表示
		drawFormula();
		
		// 図形の表示
		drawShape();
		
		// テキストの表示
		drawText();
		cs.update();
	}
	catch(e)
	{
		alert("loadContent:" + e.toString());
	}
}

// +----------+
// | リセット |
// +----------+
function resetHandler(e)
{
	try
	{
		if(animeFlag == false)
		{
			// 刻み値
			stepSize = 0.1;
			
			//設定吹き出し
			configArray = [];
			configArray[0] = [-30, 360, -10, 10];
			configArray[1] = [null, null];
			configArray[2] = [null, null];
			
			// 値の上限、下限、既定値
			defMin = 0;
			defMax = 5;
			defNum = 2;
			
			slider.span = stepSize;
			slider.min = defMin;
			slider.max = defMax;
			slider.prev = defNum;
			
			$("#tMin").html(defMin);
			$("#tMax").html(defMax);
			
			slider.changeSliderLine();
			slider.changeSliderPoint();
			slider.changeSliderControl();
			
			// ドラッグ関連
			dFlag = true;
			animeFlag = false;
			
			// 状態の記録エリア
			resetCapture();
			
			// チェックボックス
			document.getElementById("check0").checked = true;
			document.getElementById("check1").checked = true;
			document.getElementById("check2").checked = true;
			document.getElementById("check3").checked = false;
			document.getElementById("check4").checked = false;
			
			// ドラッグ関連
			dFlag = true;
			
			// 初期表示に戻す
			changeGraphScale(null, null);
			changeGraphGrid(null, null);
			
			document.getElementById("xNum").innerHTML = slider.prev;
			aNum = defNum;
			
			// 刻み幅
			document.getElementById("stepText").innerHTML = stepSize;
			
			// 軸表示
			drawBaseLine();
			changeAxisPositionHandler();
			
			// 計算処理
			calcData();
			
			// 式の表示
			drawFormula();
			
			// 図形の表示
			drawShape();
			
			// テキストの表示
			drawText();
		
			// オプションメニュー画面
			setModal('optionBlock');
			setModal('spanChange');
			setMenuMode(0, 320);
			
			// ステージ更新
			cs.update();
		}
	}
	catch(e)
	{
		alert('resetHandler:' + e.toString());
	}
}
S